# Node-RED WebServices Project Guide

## Build & Execution Commands
- `npm install` - Install dependencies
- `node-red` - Start Node-RED server
- `node-red -v` - Get Node-RED version
- `node-red --safe` - Run in safe mode
- `node-red --flows flows.json` - Use specific flow file
- `npm test` - Run all tests (when configured)

## Code Style Guidelines
- **Node-RED Flows**:
  - Organize flows by functionality
  - Use meaningful node names and labels
  - Include descriptive comments on complex nodes
  - Group related nodes using subflows
- **Custom Nodes**:
  - Follow Node-RED node development pattern
  - Include proper node registration in package.json
  - Use consistent error handling with status indicators
  - Document node properties and behavior

## Development Practices
- Use environment variables for configuration
- Keep credentials in separate flow_cred.json file
- Implement proper error handling in function nodes
- Test flows thoroughly before deployment
- Create reusable subflows for common operations
- Document API endpoints with OpenAPI/Swagger when possible

## Authorship
- Include author information in custom node files
- For generated code: "Created by Claude Code (claude-3-7-sonnet-20250219)"
- Copyright: Mauro Rosero P. <mauro@rosero.one>